@@ -4,8 +4,8 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.34'; # VERSION
-our $DATE = '2014-12-08'; # DATE
+our $VERSION = '0.35'; # VERSION
+our $DATE = '2014-12-16'; # DATE
 
 our $_complete_module = sub {
     require Complete::Module;
@@ -90,7 +90,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.34 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-12-08.
+This document describes version 0.35 of App::PMUtils (from Perl distribution App-PMUtils), released on 2014-12-16.
 
 =head1 SYNOPSIS
 
@@ -105,7 +105,7 @@ For example, L<mpath> in L<Module::Path> distribution, L<mversion> in
 L<Module::Version> distribution, etc.
 
 True. The main point of these utilities is shell tab completion, to save
-typing. For example,
+typing.
 
 =head2 For shell completion, why do you recommend the use of / (slash) instead of :: (double colon) as it should be?
 
@@ -143,7 +143,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-PMUtil
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-PMUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-PMUtils>.
 
 =head1 BUGS
 
